@@ -1,4 +1,4 @@
-// $Id: pathauto.js,v 1.4.2.1 2009/04/18 17:10:10 freso Exp $
+// $Id: pathauto.js,v 1.4.2.2 2010/02/10 21:50:30 greggles Exp $
 if (Drupal.jsEnabled) {
   $(document).ready(function() {
     if ($("#edit-pathauto-perform-alias").size() && $("#edit-pathauto-perform-alias").attr("checked")) {
@@ -20,4 +20,21 @@ if (Drupal.jsEnabled) {
       }
     });
   });
+
+  Drupal.verticalTabs = Drupal.verticalTabs || {};
+
+  Drupal.verticalTabs.path = function() {
+    var path = $('#edit-path').val();
+    var automatic = $('#edit-pathauto-perform-alias').attr('checked');
+
+    if (automatic) {
+      return Drupal.t('Automatic alias');
+    }
+    if (path) {
+      return Drupal.t('Alias: @alias', { '@alias': path });
+    }
+    else {
+      return Drupal.t('No alias');
+    }
+  }
 }
